Method: Google::Apps::Meet::V2::ConferenceRecordsService::Client#get_transcript_entry
- Defined in:
- lib/google/apps/meet/v2/conference_records_service/client.rb
#get_transcript_entry(request, options = nil) ⇒ ::Google::Apps::Meet::V2::TranscriptEntry #get_transcript_entry(name: nil) ⇒ ::Google::Apps::Meet::V2::TranscriptEntry
Gets a TranscriptEntry resource by entry ID.
Note: The transcript entries returned by the Google Meet API might not match the transcription found in the Google Docs transcript file. This can occur when the Google Docs transcript file is modified after generation.
1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 |
# File 'lib/google/apps/meet/v2/conference_records_service/client.rb', line 1251 def get_transcript_entry request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2::GetTranscriptEntryRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_transcript_entry..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Apps::Meet::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_transcript_entry.timeout, metadata: , retry_policy: @config.rpcs.get_transcript_entry.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @conference_records_service_stub.call_rpc :get_transcript_entry, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |