Class: Google::Apps::Meet::V2::ListConferenceRecordsResponse
- Inherits:
-
Object
- Object
- Google::Apps::Meet::V2::ListConferenceRecordsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/meet/v2/service.rb
Overview
Response of ListConferenceRecords method.
Instance Attribute Summary collapse
-
#conference_records ⇒ ::Array<::Google::Apps::Meet::V2::ConferenceRecord>
List of conferences in one page.
-
#next_page_token ⇒ ::String
Token to be circulated back for further List call if current List does NOT include all the Conferences.
Instance Attribute Details
#conference_records ⇒ ::Array<::Google::Apps::Meet::V2::ConferenceRecord>
Returns List of conferences in one page.
145 146 147 148 |
# File 'proto_docs/google/apps/meet/v2/service.rb', line 145 class ListConferenceRecordsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns Token to be circulated back for further List call if current List does NOT include all the Conferences. Unset if all conferences have been returned.
145 146 147 148 |
# File 'proto_docs/google/apps/meet/v2/service.rb', line 145 class ListConferenceRecordsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |