Class: Google::Apps::Meet::V2::Space
- Inherits:
-
Object
- Object
- Google::Apps::Meet::V2::Space
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/meet/v2/resource.rb
Overview
Virtual place where conferences are held. Only one active conference can be held in one space at any given time.
Instance Attribute Summary collapse
-
#active_conference ⇒ ::Google::Apps::Meet::V2::ActiveConference
Active conference, if it exists.
-
#config ⇒ ::Google::Apps::Meet::V2::SpaceConfig
Configuration pertaining to the meeting space.
-
#meeting_code ⇒ ::String
readonly
Output only.
-
#meeting_uri ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Immutable.
Instance Attribute Details
#active_conference ⇒ ::Google::Apps::Meet::V2::ActiveConference
Returns Active conference, if it exists.
57 58 59 60 |
# File 'proto_docs/google/apps/meet/v2/resource.rb', line 57 class Space include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#config ⇒ ::Google::Apps::Meet::V2::SpaceConfig
Returns Configuration pertaining to the meeting space.
57 58 59 60 |
# File 'proto_docs/google/apps/meet/v2/resource.rb', line 57 class Space include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#meeting_code ⇒ ::String (readonly)
Returns Output only. Type friendly unique string used to join the meeting.
Format: [a-z]+-[a-z]+-[a-z]+. For example, abc-mnop-xyz.
The maximum length is 128 characters.
Can only be used as an alias of the space name to get the space.
57 58 59 60 |
# File 'proto_docs/google/apps/meet/v2/resource.rb', line 57 class Space include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#meeting_uri ⇒ ::String (readonly)
Returns Output only. URI used to join meetings consisting of
https://meet.google.com/ followed by the meeting_code. For example,
https://meet.google.com/abc-mnop-xyz.
57 58 59 60 |
# File 'proto_docs/google/apps/meet/v2/resource.rb', line 57 class Space include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Immutable. Resource name of the space.
Format: spaces/{space}.
{space} is the resource identifier for the space. It's a unique,
server-generated ID and is case sensitive. For example, jQCFfuBOdN5z.
For more information, see How Meet identifies a meeting space.
57 58 59 60 |
# File 'proto_docs/google/apps/meet/v2/resource.rb', line 57 class Space include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |