Class: Google::Apps::Meet::V2::SpacesService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/apps/meet/v2/spaces_service/client.rb

Overview

Client for the SpacesService service.

REST API for services dealing with spaces.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#conference_record_path, #space_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new SpacesService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Apps::Meet::V2::SpacesService::Client.new

# Create a client using a custom configuration
client = ::Google::Apps::Meet::V2::SpacesService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the SpacesService client.

Yield Parameters:



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/google/apps/meet/v2/spaces_service/client.rb', line 135

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/apps/meet/v2/service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @spaces_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Apps::Meet::V2::SpacesService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @spaces_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the SpacesService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all SpacesService clients
::Google::Apps::Meet::V2::SpacesService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/google/apps/meet/v2/spaces_service/client.rb', line 62

def self.configure
  @configure ||= begin
    namespace = ["Google", "Apps", "Meet", "V2"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.create_space.timeout = 60.0

    default_config.rpcs.get_space.timeout = 60.0
    default_config.rpcs.get_space.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.update_space.timeout = 60.0

    default_config.rpcs.end_active_conference.timeout = 60.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the SpacesService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



105
106
107
108
# File 'lib/google/apps/meet/v2/spaces_service/client.rb', line 105

def configure
  yield @config if block_given?
  @config
end

#create_space(request, options = nil) ⇒ ::Google::Apps::Meet::V2::Space #create_space(space: nil) ⇒ ::Google::Apps::Meet::V2::Space

Creates a space.

Examples:

Basic example

require "google/apps/meet/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Apps::Meet::V2::SpacesService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Apps::Meet::V2::CreateSpaceRequest.new

# Call the create_space method.
result = client.create_space request

# The returned object is of type Google::Apps::Meet::V2::Space.
p result

Overloads:

  • #create_space(request, options = nil) ⇒ ::Google::Apps::Meet::V2::Space

    Pass arguments to create_space via a request object, either of type CreateSpaceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Apps::Meet::V2::CreateSpaceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_space(space: nil) ⇒ ::Google::Apps::Meet::V2::Space

    Pass arguments to create_space via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • space (::Google::Apps::Meet::V2::Space, ::Hash) (defaults to: nil)

      Space to be created. As of May 2023, the input space can be empty. Later on the input space can be non-empty when space configuration is introduced.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/google/apps/meet/v2/spaces_service/client.rb', line 242

def create_space request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2::CreateSpaceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_space..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Apps::Meet::V2::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_space.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_space.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @spaces_service_stub.call_rpc :create_space, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#end_active_conference(request, options = nil) ⇒ ::Google::Protobuf::Empty #end_active_conference(name: nil) ⇒ ::Google::Protobuf::Empty

Ends an active conference (if there's one).

For an example, see End active conference.

Examples:

Basic example

require "google/apps/meet/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Apps::Meet::V2::SpacesService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Apps::Meet::V2::EndActiveConferenceRequest.new

# Call the end_active_conference method.
result = client.end_active_conference request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #end_active_conference(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to end_active_conference via a request object, either of type EndActiveConferenceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Apps::Meet::V2::EndActiveConferenceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #end_active_conference(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to end_active_conference via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Resource name of the space.

      Format: spaces/{space}.

      {space} is the resource identifier for the space. It's a unique, server-generated ID and is case sensitive. For example, jQCFfuBOdN5z.

      For more information, see How Meet identifies a meeting space.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
# File 'lib/google/apps/meet/v2/spaces_service/client.rb', line 531

def end_active_conference request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2::EndActiveConferenceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.end_active_conference..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Apps::Meet::V2::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.end_active_conference.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.end_active_conference.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @spaces_service_stub.call_rpc :end_active_conference, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_space(request, options = nil) ⇒ ::Google::Apps::Meet::V2::Space #get_space(name: nil) ⇒ ::Google::Apps::Meet::V2::Space

Gets details about a meeting space.

For an example, see Get a meeting space.

Examples:

Basic example

require "google/apps/meet/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Apps::Meet::V2::SpacesService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Apps::Meet::V2::GetSpaceRequest.new

# Call the get_space method.
result = client.get_space request

# The returned object is of type Google::Apps::Meet::V2::Space.
p result

Overloads:

  • #get_space(request, options = nil) ⇒ ::Google::Apps::Meet::V2::Space

    Pass arguments to get_space via a request object, either of type GetSpaceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Apps::Meet::V2::GetSpaceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_space(name: nil) ⇒ ::Google::Apps::Meet::V2::Space

    Pass arguments to get_space via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Resource name of the space.

      Format: spaces/{space} or spaces/{meetingCode}.

      {space} is the resource identifier for the space. It's a unique, server-generated ID and is case sensitive. For example, jQCFfuBOdN5z.

      {meetingCode} is an alias for the space. It's a typeable, unique character string and is non-case sensitive. For example, abc-mnop-xyz. The maximum length is 128 characters.

      A meetingCode shouldn't be stored long term as it can become dissociated from a meeting space and can be reused for different meeting spaces in the future. Generally, a meetingCode expires 365 days after last use. For more information, see Learn about meeting codes in Google Meet.

      For more information, see How Meet identifies a meeting space.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/google/apps/meet/v2/spaces_service/client.rb', line 340

def get_space request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2::GetSpaceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_space..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Apps::Meet::V2::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_space.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_space.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @spaces_service_stub.call_rpc :get_space, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


191
192
193
# File 'lib/google/apps/meet/v2/spaces_service/client.rb', line 191

def logger
  @spaces_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


115
116
117
# File 'lib/google/apps/meet/v2/spaces_service/client.rb', line 115

def universe_domain
  @spaces_service_stub.universe_domain
end

#update_space(request, options = nil) ⇒ ::Google::Apps::Meet::V2::Space #update_space(space: nil, update_mask: nil) ⇒ ::Google::Apps::Meet::V2::Space

Updates details about a meeting space.

For an example, see Update a meeting space.

Examples:

Basic example

require "google/apps/meet/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Apps::Meet::V2::SpacesService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Apps::Meet::V2::UpdateSpaceRequest.new

# Call the update_space method.
result = client.update_space request

# The returned object is of type Google::Apps::Meet::V2::Space.
p result

Overloads:

  • #update_space(request, options = nil) ⇒ ::Google::Apps::Meet::V2::Space

    Pass arguments to update_space via a request object, either of type UpdateSpaceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Apps::Meet::V2::UpdateSpaceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_space(space: nil, update_mask: nil) ⇒ ::Google::Apps::Meet::V2::Space

    Pass arguments to update_space via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • space (::Google::Apps::Meet::V2::Space, ::Hash) (defaults to: nil)

      Required. Space to be updated.

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Optional. Field mask used to specify the fields to be updated in the space. If update_mask isn't provided(not set, set with empty paths, or only has "" as paths), it defaults to update all fields provided with values in the request. Using "*" as update_mask will update all fields, including deleting fields not set in the request.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/google/apps/meet/v2/spaces_service/client.rb', line 435

def update_space request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2::UpdateSpaceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_space..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Apps::Meet::V2::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.space&.name
    header_params["space.name"] = request.space.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_space.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_space.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @spaces_service_stub.call_rpc :update_space, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end