Class: Google::Apps::Meet::V2::Transcript
- Inherits:
-
Object
- Object
- Google::Apps::Meet::V2::Transcript
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/meet/v2/resource.rb
Overview
Metadata for a transcript generated from a conference. It refers to the ASR (Automatic Speech Recognition) result of user's speech during the conference.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#docs_destination ⇒ ::Google::Apps::Meet::V2::DocsDestination
readonly
Output only.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#state ⇒ ::Google::Apps::Meet::V2::Transcript::State
readonly
Output only.
Instance Attribute Details
#docs_destination ⇒ ::Google::Apps::Meet::V2::DocsDestination (readonly)
Returns Output only. Where the Google Docs transcript is saved.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'proto_docs/google/apps/meet/v2/resource.rb', line 317 class Transcript include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Current state of the transcript session. module State # Default, never used. STATE_UNSPECIFIED = 0 # An active transcript session has started. STARTED = 1 # This transcript session has ended, but the transcript file hasn't been # generated yet. ENDED = 2 # Transcript file is generated and ready to download. FILE_GENERATED = 3 end end |
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the transcript stopped.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'proto_docs/google/apps/meet/v2/resource.rb', line 317 class Transcript include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Current state of the transcript session. module State # Default, never used. STATE_UNSPECIFIED = 0 # An active transcript session has started. STARTED = 1 # This transcript session has ended, but the transcript file hasn't been # generated yet. ENDED = 2 # Transcript file is generated and ready to download. FILE_GENERATED = 3 end end |
#name ⇒ ::String (readonly)
Returns Output only. Resource name of the transcript.
Format: conferenceRecords/{conference_record}/transcripts/{transcript},
where {transcript} is a 1:1 mapping to each unique transcription session
of the conference.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'proto_docs/google/apps/meet/v2/resource.rb', line 317 class Transcript include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Current state of the transcript session. module State # Default, never used. STATE_UNSPECIFIED = 0 # An active transcript session has started. STARTED = 1 # This transcript session has ended, but the transcript file hasn't been # generated yet. ENDED = 2 # Transcript file is generated and ready to download. FILE_GENERATED = 3 end end |
#start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the transcript started.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'proto_docs/google/apps/meet/v2/resource.rb', line 317 class Transcript include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Current state of the transcript session. module State # Default, never used. STATE_UNSPECIFIED = 0 # An active transcript session has started. STARTED = 1 # This transcript session has ended, but the transcript file hasn't been # generated yet. ENDED = 2 # Transcript file is generated and ready to download. FILE_GENERATED = 3 end end |
#state ⇒ ::Google::Apps::Meet::V2::Transcript::State (readonly)
Returns Output only. Current state.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'proto_docs/google/apps/meet/v2/resource.rb', line 317 class Transcript include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Current state of the transcript session. module State # Default, never used. STATE_UNSPECIFIED = 0 # An active transcript session has started. STARTED = 1 # This transcript session has ended, but the transcript file hasn't been # generated yet. ENDED = 2 # Transcript file is generated and ready to download. FILE_GENERATED = 3 end end |